==> h-orm-1.0.2-sources.jar: cn/sylinx/horm/proxy/command/invoker/BeanPageCommandInvoker.java <==
package cn.sylinx.horm.proxy.command.invoker;

import java.util.Map;

import cn.sylinx.horm.core.SqlClient;
import cn.sylinx.horm.proxy.command.CommandMethodMetadata;
import cn.sylinx.horm.resource.ClasspathSqlResource;
import cn.sylinx.horm.util.Tuple;

class BeanPageCommandInvoker extends AbstractCommandInvoker {

    @Override
    public Object invoke(CommandMethodMetadata methodMetadata, Tuple tuple) {

        Map<String, Object> params = tuple.getObject(0);
        String truelyDatasource = tuple.getObject(3);
        String nativeSql = methodMetadata.getResource().nativeSql();
        int pageNumber = tuple.getObject(1);
        int pageSize = tuple.getObject(2);
        Class<?> truelyReturnType = methodMetadata.getTruelyReturnType();
        String sql = methodMetadata.getResource().sql();
        SqlClient ormClient = getClient(truelyDatasource);
        String parseSqlType = getParseSqlType(methodMetadata.getResource().parseSqlType());
        
        // 使用native sql
        boolean isNativeSql = nativeSql != null && !"".equals(nativeSql.trim());
        if (isNativeSql) {
            Tuple t = ormClient.getSqlParser().parseSql(nativeSql, parseSqlType, params);
            String truelyNativeSql = t.getObject(0);
            Object[] truelyParams = t.getObject(1);
            return ormClient.queryPage(truelyNativeSql, pageNumber, pageSize, truelyParams, truelyReturnType);
        }

        return ormClient.queryPage(new ClasspathSqlResource(sql, parseSqlType), pageNumber, pageSize, params, truelyReturnType);
    }
}

==> h-orm-1.1.0.0-sources.jar: cn/sylinx/horm/proxy/command/invoker/BeanPageCommandInvoker.java <==
package cn.sylinx.horm.proxy.command.invoker;

import java.util.Map;

import cn.sylinx.horm.core.SqlClient;
import cn.sylinx.horm.proxy.command.CommandMethodMetadata;
import cn.sylinx.horm.resource.ClasspathSqlResource;
import cn.sylinx.horm.util.Tuple;

class BeanPageCommandInvoker extends AbstractCommandInvoker {

    @Override
    public Object invoke(CommandMethodMetadata methodMetadata, Tuple tuple) {

        Map<String, Object> params = tuple.getObject(0);
        String truelyDatasource = tuple.getObject(3);
        String nativeSql = methodMetadata.getResource().nativeSql();
        int pageNumber = tuple.getObject(1);
        int pageSize = tuple.getObject(2);
        Class<?> truelyReturnType = methodMetadata.getTruelyReturnType();
        String sql = methodMetadata.getResource().sql();
        SqlClient ormClient = getClient(truelyDatasource);
        String parseSqlType = getParseSqlType(methodMetadata.getResource().parseSqlType());
        
        // 使用native sql
        boolean isNativeSql = nativeSql != null && !nativeSql.trim().isEmpty();
        if (isNativeSql) {
            Tuple t = ormClient.parseSql(nativeSql, parseSqlType, params);
            String truelyNativeSql = t.getObject(0);
            Object[] truelyParams = t.getObject(1);
            return ormClient.queryPage(truelyNativeSql, pageNumber, pageSize, truelyParams, truelyReturnType);
        }

        return ormClient.queryPage(new ClasspathSqlResource(sql, parseSqlType), pageNumber, pageSize, params, truelyReturnType);
    }
}
